@@ -49,7 +49,7 @@ class TestPath:
             with temp_dir(tempfolder) as tempdir:
                 assert tempdir == expected_dir
                 raise ValueError("Fail!")
-        except:
+        except ValueError:
             pass
         assert exists(tempdir) is False
 
@@ -64,7 +64,7 @@ class TestPath:
             ) as tempdir:
                 assert tempdir == expected_dir
                 raise ValueError("Fail!")
-        except:
+        except ValueError:
             pass
         assert exists(tempdir) is False
 
@@ -80,7 +80,7 @@ class TestPath:
             ) as tempdir:
                 assert tempdir == expected_dir
                 raise ValueError("Fail!")
-        except:
+        except ValueError:
             pass
         assert exists(tempdir) is True
 
@@ -95,7 +95,7 @@ class TestPath:
             ) as tempdir:
                 assert tempdir == expected_dir
                 raise ValueError("Fail!")
-        except:
+        except ValueError:
             pass
         assert exists(tempdir) is True
         rmtree(tempdir)
@@ -112,7 +112,7 @@ class TestPath:
             ) as tempdir:
                 assert tempdir == expected_dir
                 raise ValueError("Fail!")
-        except:
+        except ValueError:
             pass
         assert exists(tempdir) is False
 
@@ -128,7 +128,9 @@ class TestPath:
         ]
         expected_batch_file = join(expected_dir, "batch.txt")
         result = list()
-        for info, nextdict in progress_storing_tempdir(tempfolder, iterator, "iso3"):
+        for info, nextdict in progress_storing_tempdir(
+            tempfolder, iterator, "iso3"
+        ):
             assert info["folder"] == expected_dir
             expected_batch = load_file_to_str(expected_batch_file, strip=True)
             result.append(nextdict)
@@ -138,7 +140,9 @@ class TestPath:
 
         monkeypatch.setenv("WHERETOSTART", "iso3=SDN")
         result = list()
-        for info, nextdict in progress_storing_tempdir(tempfolder, iterator, "iso3"):
+        for info, nextdict in progress_storing_tempdir(
+            tempfolder, iterator, "iso3"
+        ):
             assert exists(info["folder"]) is True
             assert info["folder"] == expected_dir
             expected_batch = load_file_to_str(expected_batch_file, strip=True)
@@ -155,11 +159,13 @@ class TestPath:
                 if nextdict["iso3"] == "YEM":
                     start_batch = info["batch"]
                     raise ValueError("Problem!")
-        except:
+        except ValueError:
             pass
         assert exists(expected_dir) is True
         result = list()
-        for info, nextdict in progress_storing_tempdir(tempfolder, iterator, "iso3"):
+        for info, nextdict in progress_storing_tempdir(
+            tempfolder, iterator, "iso3"
+        ):
             assert exists(info["folder"]) is True
             assert info["folder"] == expected_dir
             assert info["batch"] == start_batch
@@ -174,12 +180,14 @@ class TestPath:
                 if nextdict["iso3"] == "YEM":
                     start_batch = info["batch"]
                     raise ValueError("Problem!")
-        except:
+        except ValueError:
             pass
         assert exists(expected_dir) is True
         monkeypatch.setenv("WHERETOSTART", "RESET")
         result = list()
-        for info, nextdict in progress_storing_tempdir(tempfolder, iterator, "iso3"):
+        for info, nextdict in progress_storing_tempdir(
+            tempfolder, iterator, "iso3"
+        ):
             assert exists(info["folder"]) is True
             assert info["folder"] == expected_dir
             assert info["batch"] != start_batch
@@ -195,12 +203,14 @@ class TestPath:
                 if nextdict["iso3"] == "YEM":
                     start_batch = info["batch"]
                     raise ValueError("Problem!")
-        except:
+        except ValueError:
             pass
         assert exists(expected_dir) is True
         monkeypatch.setenv("WHERETOSTART", "iso3=SDN")
         result = list()
-        for info, nextdict in progress_storing_tempdir(tempfolder, iterator, "iso3"):
+        for info, nextdict in progress_storing_tempdir(
+            tempfolder, iterator, "iso3"
+        ):
             assert exists(info["folder"]) is True
             assert info["folder"] == expected_dir
             assert info["batch"] == start_batch
@@ -216,7 +226,7 @@ class TestPath:
                 if nextdict["iso3"] == "YEM":
                     start_batch = info["batch"]
                     raise ValueError("Problem!")
-        except:
+        except ValueError:
             pass
         monkeypatch.setenv("WHERETOSTART", "iso3=NOTFOUND")
         found = False
@@ -270,22 +280,38 @@ class TestPath:
             ),
             (
                 1,
-                {"folder": "/tmp/gaga/1", "batch": "1234", "progress": "iso3=AFG"},
+                {
+                    "folder": "/tmp/gaga/1",
+                    "batch": "1234",
+                    "progress": "iso3=AFG",
+                },
                 {"iso3": "AFG", "name": "Afghanistan"},
             ),
             (
                 1,
-                {"folder": "/tmp/gaga/1", "batch": "1234", "progress": "iso3=SDN"},
+                {
+                    "folder": "/tmp/gaga/1",
+                    "batch": "1234",
+                    "progress": "iso3=SDN",
+                },
                 {"iso3": "SDN", "name": "Sudan"},
             ),
             (
                 1,
-                {"folder": "/tmp/gaga/1", "batch": "1234", "progress": "iso3=YEM"},
+                {
+                    "folder": "/tmp/gaga/1",
+                    "batch": "1234",
+                    "progress": "iso3=YEM",
+                },
                 {"iso3": "YEM", "name": "Yemen"},
             ),
             (
                 1,
-                {"folder": "/tmp/gaga/1", "batch": "1234", "progress": "iso3=ZAM"},
+                {
+                    "folder": "/tmp/gaga/1",
+                    "batch": "1234",
+                    "progress": "iso3=ZAM",
+                },
                 {"iso3": "ZAM", "name": "Zambia"},
             ),
         ]
@@ -301,14 +327,14 @@ class TestPath:
                 if "iso3" in nextdict and nextdict["iso3"] == "YEM":
                     start_batch = info["batch"]
                     raise ValueError("Problem!")
-        except:
+        except ValueError:
             pass
         for result in expected_results:
             result[1]["batch"] = start_batch
         assert results == expected_results[:4]
         assert exists(expected_dir) is True
         result = list()
-        for i, info, nextdict in multiple_progress_storing_tempdir(
+        for _, info, nextdict in multiple_progress_storing_tempdir(
             tempfolder, iterators, keys
         ):
             assert exists(info["folder"]) is True
@@ -319,13 +345,13 @@ class TestPath:
         assert exists(expected_dir) is False
 
         try:
-            for i, info, nextdict in multiple_progress_storing_tempdir(
+            for _, info, nextdict in multiple_progress_storing_tempdir(
                 tempfolder, iterators, keys
             ):
                 if "iso3" in nextdict and nextdict["iso3"] == "YEM":
                     start_batch = info["batch"]
                     raise ValueError("Problem!")
-        except:
+        except ValueError:
             pass
         for result in expected_results:
             result[1]["batch"] = start_batch
@@ -343,20 +369,20 @@ class TestPath:
         monkeypatch.delenv("WHERETOSTART")
 
         try:
-            for i, info, nextdict in multiple_progress_storing_tempdir(
+            for _, info, nextdict in multiple_progress_storing_tempdir(
                 tempfolder, iterators, keys
             ):
                 if "iso3" in nextdict and nextdict["iso3"] == "YEM":
                     start_batch = info["batch"]
                     raise ValueError("Problem!")
-        except:
+        except ValueError:
             pass
         for result in expected_results:
             result[1]["batch"] = start_batch
         assert exists(expected_dir) is True
         monkeypatch.setenv("WHERETOSTART", "iso3=SDN")
         result = list()
-        for i, info, nextdict in multiple_progress_storing_tempdir(
+        for _, info, nextdict in multiple_progress_storing_tempdir(
             tempfolder, iterators, keys
         ):
             assert exists(info["folder"]) is True
